VerifyResult

Type Alias VerifyResult 

pub type VerifyResult = Result<bool, Error>;
VerifyResult is the result type to represent the result of block verification

Ok(true) : it’s a newly verified block Ok(false): it’s a block is a uncle block, not verified Err(err) : it’s a block which failed to verify

Aliased Type

pub enum VerifyResult {
    Ok(bool),
    Err(Error),
}

Variants

1.0.0

Ok(bool)

Contains the success value

1.0.0

Err(Error)

Contains the error value