pub type VerifyResult = Result<bool, Error>;Expand description
VerifyResult is the result type to represent the result of block verification
Ok(true) : it’s a newly verified block Ok(false): it’s a block is a uncle block, not verified Err(err) : it’s a block which failed to verify
Aliased Type
pub enum VerifyResult {
Ok(bool),
Err(Error),
}